@@ -22,26 +22,31 @@
 #include "core/course.h"
 #include "core/unit.h"
 #include "core/phrase.h"
+#include "core/language.h"
 
 #include <QAbstractListModel>
 #include <QSignalMapper>
 
-#include <KLocale>
-#include <KDebug>
+#include <KLocalizedString>
+#include "artikulate_debug.h"
 
 UnitModel::UnitModel(QObject *parent)
     : QAbstractListModel(parent)
-    , m_course(0)
+    , m_course(nullptr)
     , m_signalMapper(new QSignalMapper(this))
+{
+    connect(m_signalMapper, SIGNAL(mapped(int)), SLOT(emitUnitChanged(int)));
+}
+
+QHash< int, QByteArray > UnitModel::roleNames() const
 {
     QHash<int, QByteArray> roles;
     roles[TitleRole] = "title";
     roles[ContainsTrainingData] = "containsTrainingData";
     roles[IdRole] = "id";
     roles[DataRole] = "dataRole";
-    setRoleNames(roles);
 
-    connect(m_signalMapper, SIGNAL(mapped(int)), SLOT(emitUnitChanged(int)));
+    return roles;
 }
 
 void UnitModel::setCourse(Course *course)
@@ -59,10 +64,10 @@ void UnitModel::setCourse(Course *course)
     m_course = course;
 
     if (m_course) {
-        connect(m_course, SIGNAL(unitAboutToBeAdded(Unit*,int)), SLOT(onUnitAboutToBeAdded(Unit*,int)));
-        connect(m_course, SIGNAL(unitAdded()), SLOT(onUnitAdded()));
-        connect(m_course, SIGNAL(unitAboutToBeRemoved(int,int)), SLOT(onUnitsAboutToBeRemoved(int,int)));
-        connect(m_course, SIGNAL(unitRemoved()), SLOT(onUnitsRemoved()));
+        connect(m_course, &Course::unitAboutToBeAdded, this, &UnitModel::onUnitAboutToBeAdded);
+        connect(m_course, &Course::unitAdded, this, &UnitModel::onUnitAdded);
+        connect(m_course, &Course::unitsAboutToBeRemoved, this, &UnitModel::onUnitsAboutToBeRemoved);
+        connect(m_course, &Course::unitsRemoved, this, &UnitModel::onUnitsRemoved);
     }
 
     endResetModel();
