@@ -1,5 +1,5 @@
 /*
- *  Copyright 2013  Andreas Cord-Landwehr <cordlandwehr@kde.org>
+ *  Copyright 2013-2015  Andreas Cord-Landwehr <cordlandwehr@kde.org>
  *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of the GNU General Public License as
@@ -41,18 +41,22 @@ public:
         DataRole                        //!< access to Unit object
     };
 
-    explicit UnitModel(QObject *parent = 0);
+    explicit UnitModel(QObject *parent = nullptr);
+    /**
+     * Reimplemented from QAbstractListModel::roleNames()
+     */
+    virtual QHash<int,QByteArray> roleNames() const Q_DECL_OVERRIDE;
     void setCourse(Course *course);
     Course * course() const;
-    QVariant data(const QModelIndex &index, int role = Qt::DisplayRole) const;
-    int rowCount(const QModelIndex &parent = QModelIndex()) const;
-    QVariant headerData(int section, Qt::Orientation orientation, int role = Qt::DisplayRole) const;
+    virtual QVariant data(const QModelIndex &index, int role = Qt::DisplayRole) const Q_DECL_OVERRIDE;
+    virtual int rowCount(const QModelIndex &parent = QModelIndex()) const Q_DECL_OVERRIDE;
+    virtual QVariant headerData(int section, Qt::Orientation orientation, int role = Qt::DisplayRole) const Q_DECL_OVERRIDE;
 
-signals:
+Q_SIGNALS:
     void unitChanged(int index);
     void courseChanged();
 
-private slots:
+private Q_SLOTS:
     void onUnitAboutToBeAdded(Unit *unit, int index);
     void onUnitAdded();
     void onUnitsAboutToBeRemoved(int first, int last);
